==============================
PyGerber package documentation
==============================

PyGerber is a Python library for 2D and 3D rendering of Gerber X3 files.
It is completely written in Python, and only dependencies are limiting its portability.

========
Contents
========

.. toctree::
   :maxdepth: 2

   readme
   installation
   usage/index
   reference/modules
   contributing
   authors
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
